% run_distributed_parallel_job.m
%   Run a parallel Matlab job on a cluster with a pool of 48 Matlab workers across 4 compute nodes.

% First initialize a cluster object based on an existing cluster profile,
% in this case we are using the 'condo R2019b' profile.
c = parcluster('condo R2019b')

% Use the AdditionalProperties property of the cluster object to set job specific details:
c.AdditionalProperties.NumNodes = 4;                           % Number of nodes requested 
c.AdditionalProperties.EmailAddress = 'your_netid@iastate.edu';  % Your Email address (please modify).
c.AdditionalProperties.ProcsPerNode = 16;                      % Number of processors per node.
c.AdditionalProperties.WallTime = '3:00:00';                   % Max wall time
c.AdditionalProperties.QueueName = 'compute';
c.AdditionalProperties.AdditionalSubmitArgs = '';

% Other properties often needed:
% To set a specific queue name, in this case to use the 'freecompute' free tier:
%        c.AdditionalProperties.QueueName = 'freecompute';
% To set the Slurm job name.  (if not set, Matlab will use "JobN" where N is determined by Matlab):
%        c.AdditionalProperties.AdditionalSubmitArgs = '--job-name=xxx';
% NOTE: The value of AdditionalProperties.AdditionalSubmitArgs is simply added on to the sbatch command. 

% Start a job timer for recording the elapsed time for the job:
tic

% The batch command below creates a Matlab job with 48 pool workers, one
% per CPU.  Each worker will do a portion of the computation in the parallel_eigen function.
% A handle to the job object is created called 'myjob'.
% NOTE: Matlab will add an additional worker to the pool for its own use so be 
% sure that the number of processors requested from Slurm (NumNodes X ProcsPerNode)
% is greater than the total number of workers needed by Matlab.
% Also, set the parameter AutoAddClientPath to false so that Matlab won't complain when paths on 
% your desktop don't exist on the compute node (this is typical and can be ignored).

myjob = batch(c,'parallel_eigen','pool', 48, 'AutoAddClientPath',false)

% see https://www.mathworks.com/help/parallel-computing/batch.html for additional tips and examples.


% Wait for the job to finish.  
wait(myjob)

% load the 'E' array from the job results. (The values for 'E' are calculated in parallel_eigen.m):

load(myjob,'E');

%-- plot the results --%
plot(E);

% print the elapsed time for the job:
toc
